@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2024 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,9 +21,9 @@ public:
     ~GravatarConfigureSettingsDialog() override;
 
 private:
-    void slotRestoreDefault();
-    void save();
-    void load();
-    GravatarConfigureSettingsWidget *mGravatarConfigureSettings;
+    GRAVATAR_NO_EXPORT void slotRestoreDefault();
+    GRAVATAR_NO_EXPORT void save();
+    GRAVATAR_NO_EXPORT void load();
+    GravatarConfigureSettingsWidget *mGravatarConfigureSettings = nullptr;
 };
 }
